@@ -23,6 +23,7 @@ import os
 from rpaths import Path
 import sqlite3
 import sys
+import traceback
 
 from reprozip import __version__ as reprozip_version
 from reprozip import _pytracer
@@ -35,6 +36,9 @@ import reprozip.traceutils
 from reprozip.utils import PY3, unicode_, stderr
 
 
+logger = logging.getLogger('reprozip')
+
+
 safe_shell_chars = set("ABCDEFGHIJKLMNOPQRSTUVWXYZ"
                        "abcdefghijklmnopqrstuvwxyz"
                        "0123456789"
@@ -161,10 +165,9 @@ def testrun(args):
             argv = [args.arg0] + args.cmdline[1:]
         else:
             argv = args.cmdline
-        logging.debug("Starting tracer, binary=%r, argv=%r",
-                      args.cmdline[0], argv)
-        c = _pytracer.execute(args.cmdline[0], argv, database.path,
-                              args.verbosity)
+        logger.debug("Starting tracer, binary=%r, argv=%r",
+                     args.cmdline[0], argv)
+        c = _pytracer.execute(args.cmdline[0], argv, database.path)
         print("\n\n-----------------------------------------------------------"
               "--------------------")
         print_db(database)
@@ -174,6 +177,8 @@ def testrun(args):
                       "signal %d" % (c & 0xFF))
             else:
                 print("\nWarning: program exited with non-zero code %d" % c)
+
+        return c
     finally:
         database.remove()
 
@@ -188,7 +193,7 @@ def trace(args):
     else:
         argv = args.cmdline
     if args.append and args.overwrite:
-        logging.critical("You can't use both --continue and --overwrite")
+        logger.critical("You can't use both --continue and --overwrite")
         sys.exit(2)
     elif args.append:
         append = True
@@ -196,15 +201,16 @@ def trace(args):
         append = False
     else:
         append = None
-    reprozip.tracer.trace.trace(args.cmdline[0],
-                                argv,
-                                Path(args.dir),
-                                append,
-                                args.verbosity)
+    status = reprozip.tracer.trace.trace(args.cmdline[0],
+                                         argv,
+                                         Path(args.dir),
+                                         append,
+                                         args.verbosity)
     reprozip.tracer.trace.write_configuration(Path(args.dir),
                                               args.identify_packages,
                                               args.find_inputs_outputs,
                                               overwrite=False)
+    return status
 
 
 def reset(args):
@@ -227,7 +233,7 @@ def pack(args):
     target = Path(args.target)
     if not target.unicodename.lower().endswith('.rpz'):
         target = Path(target.path + b'.rpz')
-        logging.warning("Changing output filename to %s", target.unicodename)
+        logger.warning("Changing output filename to %s", target.unicodename)
     reprozip.pack.pack(target, Path(args.dir), args.identify_packages)
 
 
@@ -258,7 +264,7 @@ def combine(args):
 
 def usage_report(args):
     if bool(args.enable) == bool(args.disable):
-        logging.critical("What do you want to do?")
+        logger.critical("What do you want to do?")
         sys.exit(2)
     enable_usage_report(args.enable)
     sys.exit(0)
@@ -277,7 +283,7 @@ def main():
                      "Versions before 2.7.3 are affected by bug 13676 and "
                      "will not work with ReproZip\n" %
                      sys.version.split(' ', 1)[0])
-        sys.exit(1)
+        sys.exit(125)
 
     # Parses command-line
 
@@ -383,10 +389,14 @@ def main():
         parser.error("missing command-line")
     record_usage(command=args.selected_command)
     try:
-        args.func(args)
+        status = args.func(args)
     except Exception as e:
+        traceback.print_exc()
         submit_usage_report(result=type(e).__name__)
-        raise
+        sys.exit(125)
     else:
         submit_usage_report(result='success')
-    sys.exit(0)
+    if status is None:
+        sys.exit(0)
+    else:
+        sys.exit(int(status))
