@@ -11,6 +11,7 @@ generation logic for the config YAML file.
 
 from __future__ import division, print_function, unicode_literals
 
+import warnings
 from collections import defaultdict
 from itertools import count
 import logging
@@ -31,6 +32,9 @@ from reprozip.utils import PY3, izip, iteritems, itervalues, \
     unicode_, flatten, UniqueNames, hsize, normalize_path, find_all_links
 
 
+logger = logging.getLogger('reprozip')
+
+
 class TracedFile(File):
     """Override of `~reprozip.common.File` that reads stats from filesystem.
 
@@ -96,7 +100,7 @@ def run_filter_plugins(files, input_files):
         func = entry_point.load()
         name = entry_point.name
 
-        logging.info("Running filter plugin %s", name)
+        logger.info("Running filter plugin %s", name)
         func(files=files, input_files=input_files)
 
 
@@ -226,13 +230,13 @@ def get_files(conn):
         if fi.what == TracedFile.READ_THEN_WRITTEN and
         not any(fi.path.lies_under(m) for m in magic_dirs)]
     if read_then_written_files:
-        logging.warning(
+        logger.warning(
             "Some files were read and then written. We will only pack the "
             "final version of the file; reproducible experiments shouldn't "
             "change their input files")
-        logging.info("Paths:\n%s",
-                     ", ".join(unicode_(fi.path)
-                               for fi in read_then_written_files))
+        logger.info("Paths:\n%s",
+                    ", ".join(unicode_(fi.path)
+                              for fi in read_then_written_files))
 
     files = set(
         fi
@@ -292,13 +296,22 @@ def tty_prompt(prompt, chars):
             ostream.flush()
 
 
-def trace(binary, argv, directory, append, verbosity=1):
+def trace(binary, argv, directory, append, verbosity='unset'):
     """Main function for the trace subcommand.
     """
+    if verbosity != 'unset':
+        warnings.warn("The 'verbosity' parameter for trace() is deprecated. "
+                      "Please set a level on the 'reprozip' logger instead.",
+                      DeprecationWarning)
+    if not isinstance(directory, Path):
+        directory = Path(directory)
+    if isinstance(binary, Path):
+        binary = binary.path
+
     cwd = Path.cwd()
     if (any(cwd.lies_under(c) for c in magic_dirs + system_dirs) and
             not cwd.lies_under('/usr/local')):
-        logging.warning(
+        logger.warning(
             "You are running this experiment from a system directory! "
             "Autodetection of non-system files will probably not work as "
             "intended")
@@ -312,40 +325,42 @@ def trace(binary, argv, directory, append, verbosity=1):
                 directory,
                 'aAdDsS')
             if r is None:
-                logging.critical(
+                logger.critical(
                     "Trace directory %s exists\n"
                     "Please use either --continue or --overwrite\n",
                     directory)
-                sys.exit(1)
+                sys.exit(125)
             elif r in 'sS':
-                sys.exit(1)
+                sys.exit(125)
             elif r in 'dD':
                 directory.rmtree()
                 directory.mkdir()
-            logging.warning(
+            logger.warning(
                 "You can use --overwrite to replace the existing trace "
                 "(or --continue to append\nwithout prompt)")
         elif append is False:
-            logging.info("Removing existing trace directory %s", directory)
+            logger.info("Removing existing trace directory %s", directory)
             directory.rmtree()
             directory.mkdir(parents=True)
     else:
         if append is True:
-            logging.warning("--continue was set but trace doesn't exist yet")
+            logger.warning("--continue was set but trace doesn't exist yet")
         directory.mkdir()
 
     # Runs the trace
     database = directory / 'trace.sqlite3'
-    logging.info("Running program")
+    logger.info("Running program")
     # Might raise _pytracer.Error
-    c = _pytracer.execute(binary, argv, database.path, verbosity)
+    c = _pytracer.execute(binary, argv, database.path)
     if c != 0:
         if c & 0x0100:
-            logging.warning("Program appears to have been terminated by "
-                            "signal %d", c & 0xFF)
+            logger.warning("Program appears to have been terminated by "
+                           "signal %d", c & 0xFF)
         else:
-            logging.warning("Program exited with non-zero code %d", c)
-    logging.info("Program completed")
+            logger.warning("Program exited with non-zero code %d", c)
+    logger.info("Program completed")
+
+    return c
 
 
 def write_configuration(directory, sort_packages, find_inputs_outputs,
@@ -409,9 +424,10 @@ def write_configuration(directory, sort_packages, find_inputs_outputs,
                 LIMIT 1
             )
             WHERE p.parent ISNULL
-            ORDER BY p.id DESC
-            LIMIT 1;
-            ''')
+            ORDER BY p.id
+            LIMIT 2147483647 OFFSET ?;
+            ''',
+            (len(runs),))
     for r_name, r_argv, r_envp, r_workingdir, r_exitcode in executions:
         # Decodes command-line
         argv = r_argv.split('\0')
